package com.miaxis.pc.controller.coach;

import java.util.List;
import java.util.Arrays;


import com.miaxis.coach.domain.CoachInfo;
import com.miaxis.coach.service.ICoachInfoService;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.utils.poi.ExcelUtil;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;

/**
 * 【教练】Controller
 *
 * @author wwl
 * @date 2021-01-15
 */
@RestController
@RequestMapping("/coach/info")
@Api(tags={"【pc-教练】"})
public class PcCoachInfoController extends BaseController{

    @Autowired
    private ICoachInfoService coachInfoService;

    /**
     * 查询教练列表
     */
    @PreAuthorize("@ss.hasPermi('coach:info:list')")
    @GetMapping("/list")
    @ApiOperation("查询教练列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<CoachInfo> list(@ModelAttribute CoachInfo coachInfo){
        startPage();
        List<CoachInfo> list = coachInfoService.queryList(coachInfo);
        return toResponsePageInfo(list);
    }

    /**
     * 导出教练列表
     */
    @PreAuthorize("@ss.hasPermi('coach:info:export')")
    @Log(title = "教练", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出教练列表Excel")
    public Response<String> export(@ModelAttribute CoachInfo coachInfo){
        List<CoachInfo> list = coachInfoService.queryList(coachInfo);
        ExcelUtil<CoachInfo> util = new ExcelUtil<CoachInfo>(CoachInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取教练详细信息
     */
    @PreAuthorize("@ss.hasPermi('coach:info:query')")
    @GetMapping(value = "/{coachnum}")
    @ApiOperation("获取教练详细信息")
    public Response<CoachInfo> getInfo(
            @ApiParam(name = "coachnum", value = "教练参数", required = true)
            @PathVariable("coachnum") String coachnum
    ){
        return Response.success(coachInfoService.getById(coachnum));
    }

    /**
     * 新增教练
     */
    @PreAuthorize("@ss.hasPermi('coach:info:add')")
    @Log(title = "教练", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增教练")
    public Response<Integer> add(@RequestBody CoachInfo coachInfo){
        return toResponse(coachInfoService.save(coachInfo) ? 1 : 0);
    }

    /**
     * 修改教练
     */
    @PreAuthorize("@ss.hasPermi('coach:info:edit')")
    @Log(title = "教练", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改教练")
    public Response<Integer> edit(@RequestBody CoachInfo coachInfo){
        return toResponse(coachInfoService.updateById(coachInfo) ? 1 : 0);
    }

    /**
     * 删除教练
     */
    @PreAuthorize("@ss.hasPermi('coach:info:remove')")
    @Log(title = "教练", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{coachnums}")
    @ApiOperation("删除教练")
    public  Response<Integer> remove(
            @ApiParam(name = "coachnums", value = "教练ids参数", required = true)
            @PathVariable String[] coachnums
    ){
        return toResponse(coachInfoService.removeByIds(Arrays.asList(coachnums)) ? 1 : 0);
    }
}
