package com.miaxis.pc.controller.school;

import java.util.List;
import java.util.Arrays;

import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.school.domain.SchoolInfo;
import com.miaxis.school.service.ISchoolInfoService;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;

/**
 * 【驾校】Controller
 *
 * @author wwl
 * @date 2021-01-18
 */
@RestController
@RequestMapping("/school/info")
@Api(tags={"【pc-驾校】"})
public class PcSchoolInfoController extends BaseController{

    @Autowired
    private ISchoolInfoService schoolInfoService;

    /**
     * 查询驾校列表
     */
    @PreAuthorize("@ss.hasPermi('school:info:list')")
    @GetMapping("/list")
    @ApiOperation("查询驾校列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<SchoolInfo> list(@ModelAttribute SchoolInfo schoolInfo){
        startPage();
        List<SchoolInfo> list = schoolInfoService.queryList(schoolInfo);
        return toResponsePageInfo(list);
    }

    /**
     * 导出驾校列表
     */
    @PreAuthorize("@ss.hasPermi('school:info:export')")
    @Log(title = "驾校", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出驾校列表Excel")
    public Response<String> export(@ModelAttribute SchoolInfo schoolInfo){
        List<SchoolInfo> list = schoolInfoService.queryList(schoolInfo);
        ExcelUtil<SchoolInfo> util = new ExcelUtil<>(SchoolInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取驾校详细信息
     */
    @PreAuthorize("@ss.hasPermi('school:info:query')")
    @GetMapping(value = "/{inscode}")
    @ApiOperation("获取驾校详细信息")
    public Response<SchoolInfo> getInfo(
            @ApiParam(name = "inscode", value = "驾校参数", required = true)
            @PathVariable("inscode") String inscode
    ){
        return Response.success(schoolInfoService.getById(inscode));
    }

    /**
     * 新增驾校
     */
    @PreAuthorize("@ss.hasPermi('school:info:add')")
    @Log(title = "驾校", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增驾校")
    public Response<Integer> add(@RequestBody SchoolInfo schoolInfo){
        return toResponse(schoolInfoService.save(schoolInfo) ? 1 : 0);
    }

    /**
     * 修改驾校
     */
    @PreAuthorize("@ss.hasPermi('school:info:edit')")
    @Log(title = "驾校", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改驾校")
    public Response<Integer> edit(@RequestBody SchoolInfo schoolInfo){
        return toResponse(schoolInfoService.updateById(schoolInfo) ? 1 : 0);
    }

    /**
     * 删除驾校
     */
    @PreAuthorize("@ss.hasPermi('school:info:remove')")
    @Log(title = "驾校", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{inscodes}")
    @ApiOperation("删除驾校")
    public  Response<Integer> remove(
            @ApiParam(name = "inscodes", value = "驾校ids参数", required = true)
            @PathVariable String[] inscodes
    ){
        return toResponse(schoolInfoService.removeByIds(Arrays.asList(inscodes)) ? 1 : 0);
    }
}
