package com.miaxis.coach.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.coach.dto.CoachInfoDTO;
import com.miaxis.coach.dto.CoachInfoVO;
import com.miaxis.common.utils.DateUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.miaxis.coach.mapper.CoachInfoMapper;
import com.miaxis.coach.domain.CoachInfo;
import com.miaxis.coach.service.ICoachInfoService;

import javax.annotation.Resource;

/**
 * 教练Service业务层处理
 *
 * @author wwl
 * @date 2021-01-07
 */
@Service
public class CoachInfoServiceImpl extends ServiceImpl<CoachInfoMapper, CoachInfo> implements ICoachInfoService {

    @Resource
    private CoachInfoMapper coachInfoMapper;

    /**
     * 查询教练
     *
     * @param coachnum 教练ID
     * @return 教练
     */
    @Override
    public CoachInfo selectCoachInfoById(String coachnum){
        return coachInfoMapper.selectCoachInfoById(coachnum);
    }

    /**
     * 查询教练列表
     *
     * @param coachInfo 教练
     * @return 教练
     */
    @Override
    public List<CoachInfo> selectCoachInfoList(CoachInfo coachInfo){
        return coachInfoMapper.selectCoachInfoList(coachInfo);
    }

    /**
     * 新增教练
     *
     * @param coachInfo 教练
     * @return 结果
     */
    @Override
    public int insertCoachInfo(CoachInfo coachInfo){
        coachInfo.setCreateTime(DateUtils.getNowDate());
        return coachInfoMapper.insertCoachInfo(coachInfo);
    }

    /**
     * 修改教练
     *
     * @param coachInfo 教练
     * @return 结果
     */
    @Override
    public int updateCoachInfo(CoachInfo coachInfo){
        coachInfo.setUpdateTime(DateUtils.getNowDate());
        return coachInfoMapper.updateCoachInfo(coachInfo);
    }

    /**
     * 批量删除教练
     *
     * @param coachnums 需要删除的教练ID
     * @return 结果
     */
    @Override
    public int deleteCoachInfoByIds(String[] coachnums){
        return coachInfoMapper.deleteCoachInfoByIds(coachnums);
    }

    /**
     * 删除教练信息
     *
     * @param coachnum 教练ID
     * @return 结果
     */
    @Override
    public int deleteCoachInfoById(String coachnum){
        return coachInfoMapper.deleteCoachInfoById(coachnum);
    }


    @Override
    public List<CoachInfoVO> selectCoachInfoUrlList(CoachInfoDTO coachInfoDTO) {
        return coachInfoMapper.selectCoachInfoUrlList(coachInfoDTO);
    }

    /**
     * pc 查询列表
     */
    @Override
    public List<CoachInfo> queryList(CoachInfo coachInfo) {
        LambdaQueryWrapper<CoachInfo> lqw = Wrappers.lambdaQuery();
        if (StringUtils.isNotBlank(coachInfo.getName())){
            lqw.like(CoachInfo::getName ,coachInfo.getName());
        }
        if (coachInfo.getSex() != null){
            lqw.eq(CoachInfo::getSex ,coachInfo.getSex());
        }
        if (StringUtils.isNotBlank(coachInfo.getInscode())){
            lqw.eq(CoachInfo::getInscode ,coachInfo.getInscode());
        }
        if (StringUtils.isNotBlank(coachInfo.getIdcard())){
            lqw.eq(CoachInfo::getIdcard ,coachInfo.getIdcard());
        }
        if (StringUtils.isNotBlank(coachInfo.getMobile())){
            lqw.eq(CoachInfo::getMobile ,coachInfo.getMobile());
        }
        if (StringUtils.isNotBlank(coachInfo.getAddress())){
            lqw.eq(CoachInfo::getAddress ,coachInfo.getAddress());
        }
        if (coachInfo.getPhoto() != null){
            lqw.eq(CoachInfo::getPhoto ,coachInfo.getPhoto());
        }
        if (StringUtils.isNotBlank(coachInfo.getDripermitted())){
            lqw.eq(CoachInfo::getDripermitted ,coachInfo.getDripermitted());
        }
        if (StringUtils.isNotBlank(coachInfo.getTeachpermitted())){
            lqw.eq(CoachInfo::getTeachpermitted ,coachInfo.getTeachpermitted());
        }
        if (StringUtils.isNotBlank(coachInfo.getDistrict())){
            lqw.eq(CoachInfo::getDistrict ,coachInfo.getDistrict());
        }
        if (coachInfo.getEmploystatus() != null){
            lqw.eq(CoachInfo::getEmploystatus ,coachInfo.getEmploystatus());
        }
        if (coachInfo.getStopTrain() != null){
            lqw.eq(CoachInfo::getStopTrain ,coachInfo.getStopTrain());
        }
        if (StringUtils.isNotBlank(coachInfo.getWechar())){
            lqw.eq(CoachInfo::getWechar ,coachInfo.getWechar());
        }
        if (StringUtils.isNotBlank(coachInfo.getOpenid())){
            lqw.eq(CoachInfo::getOpenid ,coachInfo.getOpenid());
        }
        if (coachInfo.getFabulous() != null){
            lqw.eq(CoachInfo::getFabulous ,coachInfo.getFabulous());
        }
        return this.list(lqw);
    }

}
