package com.miaxis.school.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.school.dto.SchoolInfoDTO;
import com.miaxis.school.dto.SchoolInfoEvalDTO;
import com.miaxis.school.dto.SchoolInfoEvalVO;
import com.miaxis.school.dto.SchoolInfoVO;
import com.miaxis.common.utils.DateUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.miaxis.school.mapper.SchoolInfoMapper;
import com.miaxis.school.domain.SchoolInfo;
import com.miaxis.school.service.ISchoolInfoService;

import javax.annotation.Resource;

/**
 * 驾校Service业务层处理
 *
 * @author miaxis
 * @date 2020-12-24
 */
@Service
public class SchoolInfoServiceImpl extends ServiceImpl<SchoolInfoMapper, SchoolInfo> implements ISchoolInfoService {

    @Resource
    private SchoolInfoMapper schoolInfoMapper;

    /**
     * 查询驾校
     *
     * @param inscode 驾校ID
     * @return 驾校
     */
    @Override
    public SchoolInfo selectSchoolInfoById(String inscode){
        return schoolInfoMapper.selectSchoolInfoById(inscode);
    }

    /**
     * 查询驾校列表
     *
     * @param schoolInfo 驾校
     * @return 驾校
     */
    @Override
    public List<SchoolInfo> selectSchoolInfoList(SchoolInfo schoolInfo){
        return schoolInfoMapper.selectSchoolInfoList(schoolInfo);
    }


    /**
     * 查询驾校列表
     *
     * @param schoolInfoDTO 驾校
     * @return 驾校
     */
    @Override
    public List<SchoolInfoVO> selectSchoolInfoUrlList(SchoolInfoDTO schoolInfoDTO){
        return schoolInfoMapper.selectSchoolInfoUrlList(schoolInfoDTO);
    }

    /**
     * 查询驾校列表
     *
     * @param schoolInfoEvalDTO 驾校
     * @return 驾校
     */
    @Override
    public List<SchoolInfoEvalVO> selectSchoolInfoEvalList(SchoolInfoEvalDTO schoolInfoEvalDTO) {
        return schoolInfoMapper.selectSchoolInfoEvalList(schoolInfoEvalDTO);
    }


    /**
     * 新增驾校
     *
     * @param schoolInfo 驾校
     * @return 结果
     */
    @Override
    public int insertSchoolInfo(SchoolInfo schoolInfo){
        schoolInfo.setCreateTime(DateUtils.getNowDate());
        return schoolInfoMapper.insertSchoolInfo(schoolInfo);
    }

    /**
     * 修改驾校
     *
     * @param schoolInfo 驾校
     * @return 结果
     */
    @Override
    public int updateSchoolInfo(SchoolInfo schoolInfo){
        schoolInfo.setUpdateTime(DateUtils.getNowDate());
        return schoolInfoMapper.updateSchoolInfo(schoolInfo);
    }

    /**
     * 批量删除驾校
     *
     * @param inscodes 需要删除的驾校ID
     * @return 结果
     */
    @Override
    public int deleteSchoolInfoByIds(String[] inscodes){
        return schoolInfoMapper.deleteSchoolInfoByIds(inscodes);
    }

    /**
     * 删除驾校信息
     *
     * @param inscode 驾校ID
     * @return 结果
     */
    @Override
    public int deleteSchoolInfoById(String inscode){
        return schoolInfoMapper.deleteSchoolInfoById(inscode);
    }

    /**
     * pc查询列表
     */
    @Override
    public List<SchoolInfo> queryList(SchoolInfo schoolInfo) {
        LambdaQueryWrapper<SchoolInfo> lqw = Wrappers.lambdaQuery();
        if (StringUtils.isNotBlank(schoolInfo.getName())){
            lqw.like(SchoolInfo::getName ,schoolInfo.getName());
        }
        if (StringUtils.isNotBlank(schoolInfo.getSname())){
            lqw.like(SchoolInfo::getSname ,schoolInfo.getSname());
        }
        if (StringUtils.isNotBlank(schoolInfo.getAddress())){
            lqw.eq(SchoolInfo::getAddress ,schoolInfo.getAddress());
        }
        if (StringUtils.isNotBlank(schoolInfo.getLegalPersonIdNumber())){
            lqw.eq(SchoolInfo::getLegalPersonIdNumber ,schoolInfo.getLegalPersonIdNumber());
        }
        if (StringUtils.isNotBlank(schoolInfo.getResponsiblePerson())){
            lqw.eq(SchoolInfo::getResponsiblePerson ,schoolInfo.getResponsiblePerson());
        }
        if (StringUtils.isNotBlank(schoolInfo.getLegalPersonName())){
            lqw.like(SchoolInfo::getLegalPersonName ,schoolInfo.getLegalPersonName());
        }
        if (StringUtils.isNotBlank(schoolInfo.getAreaName())){
            lqw.like(SchoolInfo::getAreaName ,schoolInfo.getAreaName());
        }
        if (StringUtils.isNotBlank(schoolInfo.getAreaCode())){
            lqw.eq(SchoolInfo::getAreaCode ,schoolInfo.getAreaCode());
        }
        if (StringUtils.isNotBlank(schoolInfo.getTel())){
            lqw.eq(SchoolInfo::getTel ,schoolInfo.getTel());
        }
        if (StringUtils.isNotBlank(schoolInfo.getWechar())){
            lqw.eq(SchoolInfo::getWechar ,schoolInfo.getWechar());
        }
        if (schoolInfo.getRegistrationDate() != null){
            lqw.eq(SchoolInfo::getRegistrationDate ,schoolInfo.getRegistrationDate());
        }
        if (StringUtils.isNotBlank(schoolInfo.getLicenseNumber())){
            lqw.eq(SchoolInfo::getLicenseNumber ,schoolInfo.getLicenseNumber());
        }
        if (StringUtils.isNotBlank(schoolInfo.getLicenseWord())){
            lqw.eq(SchoolInfo::getLicenseWord ,schoolInfo.getLicenseWord());
        }
        if (schoolInfo.getLicenseValidPeriodFrom() != null){
            lqw.eq(SchoolInfo::getLicenseValidPeriodFrom ,schoolInfo.getLicenseValidPeriodFrom());
        }
        if (schoolInfo.getLicenseValidPeriodEnd() != null){
            lqw.eq(SchoolInfo::getLicenseValidPeriodEnd ,schoolInfo.getLicenseValidPeriodEnd());
        }
        if (StringUtils.isNotBlank(schoolInfo.getCredibilityGrade())){
            lqw.eq(SchoolInfo::getCredibilityGrade ,schoolInfo.getCredibilityGrade());
        }
        if (StringUtils.isNotBlank(schoolInfo.getCredibilityScore())){
            lqw.eq(SchoolInfo::getCredibilityScore ,schoolInfo.getCredibilityScore());
        }
        if (schoolInfo.getVehicleSum() != null){
            lqw.eq(SchoolInfo::getVehicleSum ,schoolInfo.getVehicleSum());
        }
        if (schoolInfo.getRegcapital() != null){
            lqw.eq(SchoolInfo::getRegcapital ,schoolInfo.getRegcapital());
        }
        if (StringUtils.isNotBlank(schoolInfo.getBizlicense())){
            lqw.eq(SchoolInfo::getBizlicense ,schoolInfo.getBizlicense());
        }
        if (schoolInfo.getPoiLon() != null){
            lqw.eq(SchoolInfo::getPoiLon ,schoolInfo.getPoiLon());
        }
        if (schoolInfo.getPoiLat() != null){
            lqw.eq(SchoolInfo::getPoiLat ,schoolInfo.getPoiLat());
        }
        if (schoolInfo.getRemoved() != null){
            lqw.eq(SchoolInfo::getRemoved ,schoolInfo.getRemoved());
        }
        if (schoolInfo.getInitialReceiptDate() != null){
            lqw.eq(SchoolInfo::getInitialReceiptDate ,schoolInfo.getInitialReceiptDate());
        }
        if (StringUtils.isNotBlank(schoolInfo.getBusinessStatusName())){
            lqw.like(SchoolInfo::getBusinessStatusName ,schoolInfo.getBusinessStatusName());
        }
        if (StringUtils.isNotBlank(schoolInfo.getPxcx())){
            lqw.eq(SchoolInfo::getPxcx ,schoolInfo.getPxcx());
        }
        if (StringUtils.isNotBlank(schoolInfo.getYzCode())){
            lqw.eq(SchoolInfo::getYzCode ,schoolInfo.getYzCode());
        }
        return this.list(lqw);
    }

}
